@@ -1,4 +1,4 @@
-__all__ = ('UserProfilePoint', 'RussianProfilePoint', 'RussianProfileObjectPoint', 'UpdateProfileCreditScoringPoint')
+__all__ = ('UserProfilePoint', 'RussianProfilePoint', 'RussianProfileObjectPoint')
 
 from expressmoney.api import *
 
@@ -92,10 +92,6 @@ class RussianProfileReadContract(ProfileReadContract, ):
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
 
 
-class UpdateProfileCreditScoringCreateContract(Contract):
-    pass
-
-
 class RussianProfileID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -108,12 +104,6 @@ class UserProfileID(ID):
     _view_set = 'user_profile'
 
 
-class UpdateProfileCreditScoringID(ID):
-    _service = SERVICE
-    _app = 'profiles'
-    _view_set = 'update_profile_credit_scoring'
-
-
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
@@ -128,8 +118,3 @@ class RussianProfileObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractOb
     _point_id = RussianProfileID()
     _read_contract = RussianProfileReadContract
     _update_contract = RussianProfileUpdateContract
-
-
-class UpdateProfileCreditScoringPoint(CreatePointMixin, ContractPoint):
-    _point_id = UpdateProfileCreditScoringID()
-    _create_contract = UpdateProfileCreditScoringCreateContract
